var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { expect, } from "chai";
import { it, describe, } from "mocha";
import { getTestGql, NORMALIZED_OPTIONS, } from "./test/utils";
import { isDocumentNode, normalizeOptions, mergeOptions, } from "./utils";
describe("./utils", function () {
    describe("isDocumentNode()", function () {
        it("check false positive", function () {
            expect(isDocumentNode("test")).to.be.false;
        });
        it("check false negative", function () {
            expect(isDocumentNode(getTestGql())).to.be.true;
        });
    });
    describe("normalizeOptions()", function () {
        it("check for gql", function () {
            var testGql = getTestGql();
            expect(normalizeOptions(getTestGql())).to.deep.equal(__assign(__assign({}, NORMALIZED_OPTIONS), { query: testGql }));
        });
        it("check for empty", function () {
            expect(normalizeOptions({})).to.deep.equal(__assign({}, NORMALIZED_OPTIONS));
        });
        describe("check with subscribeToMore", function () {
            it("for single value", function () {
                expect(normalizeOptions({
                    subscribeToMore: {},
                })).to.deep.equal(__assign(__assign({}, NORMALIZED_OPTIONS), { subscribeToMore: [
                        {},
                    ] }));
            });
            it("check for multiple values", function () {
                expect(normalizeOptions({
                    subscribeToMore: [
                        { id: 0 },
                        { id: 1 },
                        { id: 2 },
                    ],
                })).to.deep.equal(__assign(__assign({}, NORMALIZED_OPTIONS), { subscribeToMore: [
                        { id: 0 },
                        { id: 1 },
                        { id: 2 },
                    ] }));
            });
        });
    });
    describe("mergeOptions()", function () {
        it("merge of empty objects", function () {
            expect(mergeOptions({}, {})).to.deep.equal(__assign({}, NORMALIZED_OPTIONS));
        });
        it("merge with override", function () {
            expect(mergeOptions({
                test: 0,
                var: 1,
            }, {
                var: 2
            })).to.deep.equal(__assign(__assign({}, NORMALIZED_OPTIONS), { test: 0, var: 2 }));
        });
        it("merge with concat", function () {
            expect(mergeOptions({
                subscribeToMore: { id: 0 },
            }, {
                subscribeToMore: { id: 1 },
            })).to.deep.equal(__assign(__assign({}, NORMALIZED_OPTIONS), { subscribeToMore: [
                    { id: 0 },
                    { id: 1 },
                ] }));
        });
    });
});
//# sourceMappingURL=utils.test.js.map